@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute Halstead complexity metrics
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
@@ -35,8 +35,11 @@ has [qw(
     prog_length
     est_prog_length
     volume
+    min_volume
     difficulty
     level
+    lang_level
+    intel_content
     effort
     time_to_program
     delivered_bugs
@@ -67,6 +70,11 @@ sub _build_volume {
     return $self->prog_length * _log2($self->prog_vocab);
 }
 
+sub _build_min_volume {
+    my ($self) = @_;
+    return (2 + $self->n_distinct_operands) * _log2(2 + $self->n_distinct_operands);
+}
+
 sub _build_difficulty {
     my ($self) = @_;
     return ($self->n_distinct_operators / 2)
@@ -75,7 +83,17 @@ sub _build_difficulty {
 
 sub _build_level {
     my ($self) = @_;
-    return 1 / $self->difficulty;
+    return $self->min_volume / $self->volume;
+}
+
+sub _build_lang_level {
+    my ($self) = @_;
+    return $self->volume / $self->difficulty / $self->difficulty;
+}
+
+sub _build_intel_content {
+    my ($self) = @_;
+    return $self->volume / $self->difficulty;
 }
 
 sub _build_effort {
@@ -148,8 +166,11 @@ sub dump {
     printf "Program vocabulary = %d, Program length = %d\n", $self->prog_vocab, $self->prog_length;
     printf "Estimated program length = %.3f\n", $self->est_prog_length;
     printf "Program volume = %.3f\n", $self->volume;
+    printf "Program minimum volume = %.3f\n", $self->min_volume;
     printf "Program difficulty = %.3f\n", $self->difficulty;
     printf "Program level = %.3f\n", $self->level;
+    printf "Program language level = %.3f\n", $self->lang_level;
+    printf "Program intelligence content = %.3f\n", $self->intel_content;
     printf "Program effort = %.3f\n", $self->effort;
     printf "Time to program = %.3f\n", $self->time_to_program;
     printf "Delivered bugs = %.3f\n", $self->delivered_bugs;
@@ -184,7 +205,7 @@ Perl::Metrics::Halstead - Compute Halstead complexity metrics
 
 =head1 VERSION
 
-version 0.0204
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -257,6 +278,13 @@ The estimated program length.  This is a computed attribute.
 
 The program volume.  This is a computed attribute.
 
+=head2 min_volume
+
+  $min_volume = $pmh->min_volume;
+
+The volume of the most succinct program which can be coded.  This is a computed
+attribute.
+
 =head2 difficulty
 
   $difficulty = $pmh->difficulty;
@@ -269,6 +297,18 @@ The program difficulty.  This is a computed attribute.
 
 The program level.  This is a computed attribute.
 
+=head2 lang_level
+
+  $lang_level = $pmh->lang_level;
+
+The programming language level.  This is a computed attribute.
+
+=head2 intel_content
+
+  $intel_content = $pmh->intel_content;
+
+Amount of intelligence presented in the program.  This is a computed attribute.
+
 =head2 effort
 
   $effort = $pmh->effort;
@@ -319,6 +359,8 @@ L<https://en.wikipedia.org/wiki/Halstead_complexity_measures>
 
 L<https://www.verifysoft.com/en_halstead_metrics.html>
 
+L<https://www.geeksforgeeks.org/software-engineering-halsteads-software-metrics/>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
